@@ -2,12 +2,12 @@ import PySimpleGUI as sg
 import sys
 import os
 import traceback
-import CapiPy.src.BMOD as BMOD
-import CapiPy.src.QUAT as QUAT 
-import CapiPy.src.AS_ID as AS_ID 
-import CapiPy.src.S2_analysis as S2_analysis 
-import CapiPy.src.ClusterDistance as ClusterDistance
-import CapiPy.src.Ref_retrieval as Ref_retrieval
+import CapiPy.utils.BMOD as BMOD
+import CapiPy.utils.QUAT as QUAT
+import CapiPy.utils.AS_ID as AS_ID 
+import CapiPy.utils.S2_analysis as S2_analysis 
+import CapiPy.utils.ClusterDistance as ClusterDistance
+import CapiPy.utils.Ref_retrieval as Ref_retrieval
 import webbrowser
 import json
 import subprocess
@@ -49,10 +49,8 @@ for p1 in dir:
         currentdir += p1 + '/'
         i+=1
 
-if "win" in platform:
-    workdir = os.getcwd().replace('\\', '/')
-
-settings_file = currentdir + 'ncfiles/settings_file.cfg'
+ex_loc = os.path.realpath(__file__).replace('GUI.py', '')
+settings_file =  ex_loc + 'ncfiles/settings_file.cfg'
 default_settings = {'Pymol_location': pymol_exe ,
                     'Clustalw_location': clustalw_exe,
                     'text_exe': text_exe,
@@ -104,11 +102,11 @@ def main():
         if event_main in (None, 'Exit'): 
             break
         elif event_main == "1. Blast and Modeller":
-            layout_m1 = [[sg.Text('Do you need to create a new folder?', font =('Helvetica', 10, 'bold'))], 
-                         [sg.Checkbox('Yes'), sg.Text('Enter the name:'), sg.Input()],
-                         [sg.Checkbox('No'), sg.Text('Enter the location:'), sg.Input()],
+            layout_m1 = [[sg.Text('Project name:'), sg.Input(key='-PROJECT-')],
+                         [sg.Column([[sg.Text('Folder'), sg.In(size=(25,1), 
+                         key='-FOLDER-'),sg.FolderBrowse()]], element_justification='c')],
                          [sg.Text('Please enter your protein sequence: ', font =('Helvetica', 10, 'bold'))],
-                         [sg.Multiline(size=(100, 10))],
+                         [sg.Multiline(size=(100, 10), key='-SEQUENCE-')],
                          [sg.Text('How do you want to run BLAST?', font =('Helvetica', 10, 'bold'))],
                          [sg.Checkbox('LOCAL'), sg.Checkbox('WEB')],
                          [sg.Text('Do you want to open the results directly?', font =('Helvetica', 10, 'bold')),
@@ -124,29 +122,27 @@ def main():
                     break
                 elif event_m1 == 'Run':
                     window_m1['-output-'].Update('')
-                    if values_m1[0] is True and values_m1[2] is False:
-                        folder_answer = "YES"
-                        folder_name = values_m1[1]
-                    elif values_m1[0] is False and values_m1[2] is True:
-                        folder_answer = "NO"
-                        folder_name = values_m1[3]
-                    elif values_m1[0] is False and values_m1[2] is False:
-                        checks.append("Error: create a folder or indicate its location!")
-                    else:
-                        checks.append("Error: create a folder or indicate its location, but not both!")
-                    if len(values_m1[4]) > 1:
-                        prot_sequence = values_m1[4]
+                    
+                    project_name = values_m1['-PROJECT-']
+                    directory_name = values_m1['-FOLDER-'] 
+                    folder_name = directory_name + '/' + project_name
+                    
+                    if os.path.exists(folder_name) == False:
+                        os.mkdir(folder_name)
+                    
+                    if len(values_m1['-SEQUENCE-']) > 1:
+                        prot_sequence = values_m1['-SEQUENCE-']
                     else:
                         checks.append("Error: enter your protein sequence!")
-                    if values_m1[5] is True:
+                    if values_m1[0] is True:
                         blast_response = "LOCAL"
-                    elif values_m1[6] is True:
+                    elif values_m1[1] is True:
                         blast_response == "WEB"
                     else:
                         checks.append("Error: select how you want to run BLAST!")
-                    if values_m1[7] is True:
+                    if values_m1[2] is True:
                         output_programs = "YES"
-                    elif values_m1[8] is True:
+                    elif values_m1[3] is True:
                         output_programs = "NO"
                     else:
                         checks.append("Error: Select if you want your results to be shown directly or not.")
@@ -155,23 +151,22 @@ def main():
                     redirect_stdout(window_m1['-output-'])
                     window_m1.refresh()
                     try:
-                        BMOD.main(folder_answer, folder_name, prot_sequence, blast_response, clustalw_exe)
+                        BMOD.main(folder_name, prot_sequence, blast_response, clustalw_exe)
                         if output_programs == "YES":
-                            if os.path.isfile(workdir + '/' + folder_name + '/Blast&Modeller/query_multimeric.pdb'):
+                            if os.path.isfile(folder_name + '/Blast&Modeller/query_multimeric.pdb'):
                                 subprocess.Popen([settings['Pymol_location'],
-                                                  workdir + '/' + folder_name + '/Blast&Modeller/query_monomer.pdb',
-                                                  workdir + '/' + folder_name + '/Blast&Modeller/query_multimeric.pdb',
-                                                  workdir + '/' + folder_name + '/Blast&Modeller/template.pdb'])
-                            elif not os.path.isfile(workdir + '/' + folder_name + '/Blast&Modeller/query_multimeric.pdb'):
-                                subprocess.Popen([settings['Pymol_location'], workdir +
-                                                  '/' + folder_name + '/Blast&Modeller/query_monomer.pdb',
-                                                  workdir + '/' + folder_name + '/Blast&Modeller/template.pdb'])
+                                                  folder_name + '/Blast&Modeller/query_monomer.pdb',
+                                                  folder_name + '/Blast&Modeller/query_multimeric.pdb',
+                                                  folder_name + '/Blast&Modeller/template.pdb'])
+                            elif not os.path.isfile(folder_name + '/Blast&Modeller/query_multimeric.pdb'):
+                                subprocess.Popen([settings['Pymol_location'], folder_name + '/Blast&Modeller/query_monomer.pdb',
+                                                  folder_name + '/Blast&Modeller/template.pdb'])
                             else:
                                 print("It seems CapiPy cannot find the template pdb file!")
-                        os.chdir(workdir)
+                        os.chdir(directory_name)
                     except BaseException as error:
                         print('Something went wrong...\n' + str(error))
-                        os.chdir(workdir)
+                        os.chdir(directory_name)
                 else:
                     for sent in checks:
                         print(sent)
@@ -180,13 +175,9 @@ def main():
             window_m1.close()    
        
         elif event_main == "1.1. Quaternary assembly":
-            layout_m1_1 = [[sg.Text('Enter the location of your pdb file (monomer):', 
-                                    font =('Helvetica', 10, 'bold')), sg.Input()],
-                           [sg.Text('Please indicate the monomeric model: ', 
-                                    font =('Helvetica', 10, 'bold')), 
-                            sg.Input(default_text='query_monomer.pdb')],
+            layout_m1_1 = [[sg.Text('Select your monomer pdb file:'), sg.FileBrowse(key='-FILE_MONOMER-')],
                            [sg.Text('Please indicate the template PDB code: ', 
-                                    font =('Helvetica', 10, 'bold')), sg.Input()],
+                                    font =('Helvetica', 10, 'bold')), sg.Input(key='-PDB_CODE-')],
                            [sg.Text('Do you want to open the results directly?', font =('Helvetica', 10, 'bold')),
                             sg.Checkbox('Yes', default=True), sg.Checkbox('No')],
                            [sg.Text('OUTPUT:', font =('Helvetica', 10, 'bold'))],
@@ -200,22 +191,18 @@ def main():
                 elif event_m1_1 == 'Run':
                     window_m1_1['-output-'].Update('')
                     checks = []
-                    if values_m1_1[0] != '':
-                        folder_name = values_m1_1[0]
-                    else:
-                        checks.append("Error: indicate the folder location!")
-
-                    if values_m1_1[1] != '':
-                        monomeric_model = values_m1_1[1]
+                    if values_m1_1['-PDB_CODE-'] != '':
+                        monomeric_model = values_m1_1['-FILE_MONOMER-']
+                        folder_name = os.path.split(monomeric_model)[0]
                     else:
                         checks.append("Error: indicate the monomeric pdb!")
-                    if values_m1_1[2] != '':
-                        multimeric_model = values_m1_1[2]
+                    if values_m1_1['-PDB_CODE-'] != '':
+                        multimeric_model = values_m1_1['-PDB_CODE-']
                     else:
                         checks.append("Error: indicate the template as a PDB code (four letter code)")
-                    if values_m1_1[3] is True:
+                    if values_m1_1[0] is True:
                         output_programs = "YES"
-                    elif values_m1_1[4] is True:
+                    elif values_m1_1[1] is True:
                         output_programs = "NO"
                     else:
                         checks.append("Error: Select if you want your results to be shown directly or not.")
@@ -224,25 +211,35 @@ def main():
                         redirect_stdout(window_m1_1['-output-'])
                         window_m1_1.refresh()
                         try:
-                            QUAT.main(folder_name, monomeric_model, multimeric_model, clustalw_exe)
+                            location_quat_pdb = QUAT.main(folder_name, monomeric_model, multimeric_model, clustalw_exe)
                             if output_programs == "YES":
-                                if os.path.isfile(workdir + '/' + folder_name + '/Blast&Modeller/quat_as_' +
+                                print(location_quat_pdb)
+                                if os.path.isfile(location_quat_pdb + '/quat_as_' +
                                               multimeric_model + '.pdb'):
+                                    print("one")
                                     subprocess.Popen([settings['Pymol_location'],
-                                                 workdir + '/' + folder_name + '/Blast&Modeller/quat_as_' +
+                                                 location_quat_pdb + '/quat_as_' +
                                                   multimeric_model + '.pdb',
-                                                 workdir + '/' + folder_name + '/Blast&Modeller/quat_template.pdb'])
-                                elif not os.path.isfile( workdir + '/' + folder_name + '/Blast&Modeller/quat_as_' +
+                                                 location_quat_pdb +'/quat_template.pdb'])
+                                elif os.path.isfile(location_quat_pdb + '/Quaternary/quat_as_' +
                                     multimeric_model + '.pdb'):
+                                    print("two")
                                     subprocess.Popen([settings['Pymol_location'],
-                                                  workdir + '/' + folder_name + '/Blast&Modeller/query_multimeric.pdb',
-                                                  workdir + '/' + folder_name + '/Blast&Modeller/quat_template.pdb'])
+                                                 location_quat_pdb + '/Quaternary/quat_as_' +
+                                                  multimeric_model + '.pdb',
+                                                 location_quat_pdb +'/Quaternary/quat_template.pdb'])
+                                elif not os.path.isfile('/Blast&Modeller/quat_as_' +
+                                    multimeric_model + '.pdb'):
+                                    print("three")
+                                    subprocess.Popen([settings['Pymol_location'],
+                                                  location_quat_pdb + '/query_multimeric.pdb',
+                                                  location_quat_pdb +'/quat_template.pdb'])
                                 else:
                                     print("It seems CapiPy cannot find the pdb files!")
-                            os.chdir(workdir)
+                            os.chdir(folder_name)
                         except BaseException as error:
                             print('Something went wrong...\n' + str(error))
-                            os.chdir(workdir)
+                            os.chdir(folder_name)
                     else:
                         for sent in checks:
                             print(sent)
@@ -252,13 +249,14 @@ def main():
             window_m1_1.close()
 
         elif event_main == "2. Active site ID":
-            layout_m2 = [[sg.Text('Do you need to create a new folder?', font =('Helvetica', 10, 'bold'))],
-                         [sg.Checkbox('No', default=True), sg.Text('Enter the folder location:'), sg.Input()],
-                         [sg.Checkbox('Yes'), sg.Text('Enter the name:'), sg.Input()],
-                         [sg.Text('\tIf you are creating a new folder, please indicate the protein sequence '
-                                  '- in one letter code - :')],
-                         [sg.Text('\tProtein sequence:'), sg.Multiline(size=(70, 10))],
-                         [sg.Text('\tModel protein PDB code -4 characters identifier-:'), sg.Input()],
+            layout_m2 = [[sg.Column([[sg.Text('Folder'), sg.In(size=(25,1), 
+                         key='-FOLDER-'),sg.FolderBrowse()]], element_justification='c')],
+                         [sg.Text('Have you run the Blast&Modeller for your query protein?',
+                                  font =('Helvetica', 10, 'bold'))],
+                         [sg.Checkbox('Yes', default=True), sg.Checkbox('No')],
+                         [sg.Text('\tIf you have not run the Blast&Modeller or it is not in the same folder, \n\tplease indicate the protein sequence and the model protein to use:')],
+                         [sg.Text('\tProtein sequence:'), sg.Multiline(size=(70, 10), key='-SEQUENCE-')],
+                         [sg.Text('\tModel protein PDB code -4 characters identifier-:'), sg.Input(key='-MODEL-')],
                          [sg.Text('If available, do you want to use the data in UniProt for the estimation?',
                                   font =('Helvetica', 10, 'bold'))],
                          [sg.Checkbox('Yes, use UniProt preferentially.', default=True),
@@ -276,42 +274,38 @@ def main():
                 elif event_m2 == 'Run':
                     window_m2['-output-'].Update('')
                     checks = []
-                    if values_m2[0] is True and values_m2[2] is False:
+                    folder_name = values_m2['-FOLDER-']
+                    if values_m2[0] is True and values_m2[1] is False:
                         folder_answer = "NO"
-                        if values_m2[1] != '':
-                            folder_name = values_m2[1]
-                            prot_sequence = ''
-                            model_prot = ''
-                        else:
-                            checks.append("Error: Please, enter the folder name or location!")
-                    elif values_m2[0] is False and values_m2[2] is True:
+                        prot_sequence = ''
+                        model_prot = ''
+                    elif values_m2[0] is False and values_m2[1] is True:
                         folder_answer = "YES"
-                        folder_name = values_m2[3].replace('\n', '')
-                        if len(values_m2[4]) > 0:
-                            prot_sequence = values_m2[4].replace('\n', '')
-                        if len(values_m2[5]) == 4:
-                            if values_m2[5].isalpha() is True:
+                        if len(values_m2['-SEQUENCE-']) > 0:
+                            prot_sequence = values_m2['-SEQUENCE-'].replace('\n', '')
+                        if len(values_m2['-MODEL-']) == 4:
+                            if values_m2['-MODEL-'].isalpha() is True:
                                 checks.append("Error: It seems that your format is not a PDBid.")
-                            elif values_m2[5].isnumeric() is True:
+                            elif values_m2['-MODEL-'].isnumeric() is True:
                                 checks.append("Error: Remember that PDBid are formed by letters and numbers.")
                             else:
-                                model_prot = values_m2[5]
+                                model_prot = values_m2['-MODEL-']
                         else:
                             checks.append('Error: Enter the protein sequence or select the query '
                                           'from a previously created folder!')
                     elif values_m2[0] == values_m2[2]:
                         checks.append("Error: create a folder or indicate its location!")
 
-                    if values_m2[6] is True:
+                    if values_m2[2] is True:
                         use_uniprot = 'YES'
-                    elif values_m2[7] is True:
+                    elif values_m2[3] is True:
                         use_uniprot = 'NO'
                     else:
                         checks.append("Error: Select if you want to use UniProt preferentially or not.")
 
-                    if values_m2[8] is True:
+                    if values_m2[4] is True:
                         output_programs = "YES"
-                    elif values_m2[9] is True:
+                    elif values_m2[5] is True:
                         output_programs = "NO"
                     else:
                         checks.append("Error: Select if you want your results to be shown directly or not.")
@@ -327,14 +321,14 @@ def main():
                                 webbrowser.open('https://www.uniprot.org/uniprot/' + str(uniprotID))
                                 time.sleep(3)
                                 subprocess.Popen([settings['text_exe'],
-                                                  workdir + '/' + folder_name + '/ActiveSite/Active_site.txt'])
+                                                 folder_name + '/ActiveSite/Active_site.txt'])
                                 time.sleep(3)
                                 subprocess.Popen([settings['text_exe'],
-                                                  workdir + '/' + folder_name + '/ActiveSite/refsequp.aln'])
-                            os.chdir(workdir)
+                                                  folder_name + '/ActiveSite/refsequp.aln'])
+                            os.chdir(folder_name)
                         except BaseException as error:
                             print('Something went wrong...\n' + str(error))
-                            os.chdir(workdir)
+                            os.chdir(folder_name)
                     else:
                         for sent in checks:
                             print(sent)
@@ -344,12 +338,8 @@ def main():
             window_m2.close()
 
         elif event_main == "3. Surface and Clusters":
-            layout_m3 = [[sg.Text('Do you need to create a new folder?', font =('Helvetica', 10, 'bold'))],
-                         [sg.Checkbox('No', default=True), sg.Text('\tEnter the folder name:'), sg.Input()],
-                         [sg.Checkbox('Yes'), sg.Text('\tGive a name to the folder:'), sg.Input()],
-                         [sg.Text('Indicate the location of the pdb file to use:', 
-                                  font =('Helvetica', 10, 'bold'))],
-                         [sg.Input(default_text='query_multimeric.pdb')],
+            layout_m3 = [[sg.Column([[sg.Text('Select the PDB file:'), sg.In(size=(25,1), 
+                         key='-PDB_FILE-'),sg.FileBrowse()]], element_justification='c')],
                          [sg.Text('Active Site residues (Ex. 1, 2, 3):', font =('Helvetica', 10, 'bold'))],
                          [sg.Checkbox('ActiveSiteID results', default=True),
                           sg.Text('Or indicate residues:'), sg.Input()],
@@ -366,60 +356,40 @@ def main():
                 elif event_m3 == 'Run':
                     window_m3['-output-'].Update('')
                     checks = []
-                    if values_m3[0] is True and values_m3[2] is False:
-                        folder_answer = "NO"
-                        if values_m3[1] != "":
-                            folder_name = values_m3[1]
-                        else:
-                            checks.append("Error: Indicate the name of the folder.")
-                        
-                    elif values_m3[0] is False and values_m3[2] is True:
-                        folder_answer = 'YES'
-                        if values_m3[1] != "":
-                            folder_name = values_m3[3]
-                        else:
-                            checks.append("Error: Indicate the name of the folder.")
-                    elif values_m3[0] == values_m3[2]:
-                        checks.append('Error: Select a folder or create a new one.')   
-                         
-                    if values_m3[4] != '':
-                        pdbfile = values_m3[4]
-                    else:
-                            checks.append('Error: Indicate the name of the pdb file!')
-    
-                    if values_m3[5] is True:
+                    pdbfile = values_m3['-PDB_FILE-'] 
+                    folder_name = os.path.split(pdbfile)[0]
+                    if values_m3[0] is True:
                         active_site = 'YES'
-                    elif values_m3[5] is False and len(values_m3[6]) > 0:
-                        active_site = values_m3[6].replace(" ", "").split(",")
+                    elif values_m3[1] is False and len(values_m3[6]) > 0:
+                        active_site = values_m3[2].replace(" ", "").split(",")
                     else:
                         checks.append("Error: Untick the box or indicate the active site residues!")
-
-                    if values_m3[7] is True:
+                    if values_m3[2] is True:
                         output_programs = "YES"
-                    elif values_m3[8] is True:
+                    elif values_m3[3] is True:
                         output_programs = "NO"
                     else:
                         checks.append("Error: Select if you want your results to be shown directly or not.")
-
+                        
                     if len(checks) == 0:
                         print('Module running, be patient. This can take a few minutes...\n')
                         redirect_stdout(window_m3['-output-'])
                         window_m3.refresh()
                         try:
-                            S2_analysis.main(folder_answer, folder_name, pdbfile, active_site)
+                            S2_analysis.main(folder_name, pdbfile, active_site)
                             if output_programs == 'YES':
                                 try:
                                     subprocess.Popen([settings['Pymol_location'],
-                                             workdir + '/' + folder_name + '/Size&Clusters/query.pdb',
-                                              workdir + '/' + folder_name + '/Size&Clusters/PyMol_clusters.pml'])
+                                             folder_name + '/Size&Clusters/query.pdb',
+                                             folder_name + '/Size&Clusters/PyMol_clusters.pml'])
                                     subprocess.Popen([settings['text_exe'],
-                                             workdir + '/' + folder_name + '/Size&Clusters/General_info.txt'])
+                                             folder_name + '/Size&Clusters/General_info.txt'])
                                 except BaseException:
                                     print("It seems CapiPy cannot find the template pdb file!")
-                            os.chdir(workdir)
+                            os.chdir(folder_name)
                         except BaseException:
                             print('Something went wrong...\n' + traceback.format_exc())
-                            os.chdir(workdir)
+                            os.chdir(folder_name)
                     else:
                         for sent in checks:
                             print(sent)
@@ -430,8 +400,8 @@ def main():
        
         elif event_main == "3.1. Cluster distance":
          
-            layout_m3_1 = [[sg.Text('Enter the folder name:', font =('Helvetica', 10, 'bold'))],
-                          [sg.Input()],
+            layout_m3_1 = [[sg.Column([[sg.Text('Select the PDB file:'), sg.In(size=(25,1), 
+                          key='-PDB_FILE-'),sg.FileBrowse()]], element_justification='c')],
                           [sg.Text('Residues to calculate distance from (Ex. 1_A, 2_A, 300_B:', 
                                     font =('Helvetica', 10, 'bold'))],
                           [sg.Input()],
@@ -454,11 +424,12 @@ def main():
                     window_m3_1['-output-'].Update('')
                     checks = []
                     if len(values_m3_1[0]) > 0:
-                        folder_name = values_m3_1[0]
+                        pdbfile = values_m3_1['-PDB_FILE-']
+                        folder_name = os.path.split(pdbfile)[0]
                     else:
                         checks.append('Error: Please enter the name of the folder you want to process the data from.')
-                    if len(values_m3_1[1]) > 0:
-                        residues = values_m3_1[1].replace(" ", "").split(",")
+                    if len(values_m3_1[0]) > 0:
+                        residues = values_m3_1[0].replace(" ", "").split(",")
                         for res in residues:
                             if res.isdigit() is True:
                                 checks.append("\nError: Please, indicate the chain also!")
@@ -466,17 +437,17 @@ def main():
                                 checks.append("Error: There should be at least one number your residues.")
                             elif res == "" or res == " ":
                                 checks.append("\nError: Please, enter at least one position.")
-                    elif len(values_m3_1[1]) > 0:
+                    elif len(values_m3_1[0]) > 0:
                         checks.append('Error: Enter at least one residue identified with it\'s number and chain (Ex. 1_A)')
                 
-                    if len(values_m3_1[2]) > 0:
-                        file_name = values_m3_1[2]
+                    if len(values_m3_1[1]) > 0:
+                        file_name = values_m3_1[1]
                     else:
                         checks.append('Error: Enter the file name, please')
 
-                    if values_m3_1[3] is True:
+                    if values_m3_1[2] is True:
                         output_programs = "YES"
-                    elif values_m3_1[4] is True:
+                    elif values_m3_1[3] is True:
                         output_programs = "NO"
                     else:
                         checks.append("Error: Select if you want your results to be shown directly or not.")
@@ -486,20 +457,20 @@ def main():
                         redirect_stdout(window_m3_1['-output-'])
                         window_m3_1.refresh()
                         try:
-                            pml_file = ClusterDistance.main(folder_name, residues, file_name)
+                            pml_file = ClusterDistance.main(folder_name, pdbfile, residues, file_name)
                             print(pml_file)
                             if output_programs == "YES":
                                 try:
                                     subprocess.Popen([settings['Pymol_location'],
-                                                 workdir + '/' + folder_name + '/Size&Clusters/query.pdb',
-                                                 workdir + '/' + folder_name + '/Size&Clusters/PyMol_clusters.pml',
-                                                 workdir + '/' + folder_name + '/Size&Clusters/' + pml_file])
+                                                 folder_name + '/Size&Clusters/query.pdb',
+                                                 folder_name + '/Size&Clusters/PyMol_clusters.pml',
+                                                 folder_name + '/Size&Clusters/' + pml_file])
                                 except BaseException:
                                     print("It seems CapiPy cannot find the template pdb file!")
-                            os.chdir(workdir)
+                            os.chdir(folder_name)
                         except BaseException as error:
                             print('Something went wrong...\n' + traceback.format_exc())
-                            os.chdir(workdir)
+                            os.chdir(folder_name)
                     else:
                         for sent in checks:
                             print(sent)
@@ -510,9 +481,7 @@ def main():
     
         elif event_main == "4. Immobilization papers retrieval":
 
-            layout_m4 = [[sg.Text('Enter the folder name. You can enter an already existing folder name or'
-                                  'create a new one.', font =('Helvetica', 10, 'bold'))],
-                         [sg.Input()],
+            layout_m4 = [[sg.Text('Project name:'), sg.FolderBrowse(key='-FOLDER-')],
                          [sg.Text('Do you want to use the same query as in the other modules?',
                                   font =('Helvetica', 10, 'bold'))],
                          [sg.Checkbox('Yes'), sg.Checkbox('No')],
@@ -533,25 +502,21 @@ def main():
                 elif event_m4 == 'Run':
                     window_m4['-output-'].Update('')
                     checks = []
-                    if len(values_m4[0]) > 0:
-                        folder_name = values_m4[0]
-                    else:
-                        checks.append('Error: Please enter the name of the folder you want to process the data from.')
-
-                    if values_m4[1] is True and values_m4[2] is False:
+                    folder_name = values_m4['-FOLDER-']
+                    if values_m4[0] is True and values_m4[1] is False:
                         query = 'YES'
-                    elif values_m4[1] is False and values_m4[2] is True:
+                    elif values_m4[0] is False and values_m4[1] is True:
                         if len(values_m4[3]) > 1:
                             query = values_m4[3].replace("\n", "")
                         else:
                             checks.append('Error: please enter a valid sequence. '
                                           'Remember, it has to be as one letter amino acid code!')
-                    elif values_m4[1] == values_m4[2]:
+                    elif values_m4[0] == values_m4[1]:
                         checks.append('Error: Check ONE of the tickboxes!')
 
-                    if values_m4[3] is True:
+                    if values_m4[2] is True:
                         output_programs = "YES"
-                    elif values_m4[4] is True:
+                    elif values_m4[3] is True:
                         output_programs = "NO"
                     else:
                         checks.append("Error: Select if you want your results to be shown directly or not.")
@@ -564,11 +529,11 @@ def main():
                             Ref_retrieval.main(folder_name, query)
                             if output_programs =="YES":
                                 subprocess.Popen([settings['csv_exe'],
-                                              workdir + '/' + folder_name + '/RelevantPapers/' + 'relevant_papers.csv'])
-                            os.chdir(workdir)
+                                              folder_name + '/RelevantPapers/' + 'relevant_papers.csv'])
+                            os.chdir(folder_name)
                         except BaseException:
                             print('Something went wrong...\n' + traceback.format_exc())
-                            os.chdir(workdir)
+                            os.chdir(folder_name)
                     else:
                         for sent in checks:
                             print(sent)
